@@ -1,5 +1,6 @@
 from loopr.api.dataset.image_dataset import ImageDataset
-from loopr.api.dataset.paired_dataset import PairedDataset
+from loopr.api.dataset.sku_dataset import SkuDataset
+from loopr.api.dataset.text_dataset import TextDataset
 from loopr.exceptions import LooprInvalidResourceError
 from loopr.resources.constants import INVALID_DATASET_TYPE
 
@@ -13,7 +14,7 @@ class DatasetInitializer:
 
     def __call__(self, dataset_type):
         """
-        Initialize the Dataset Object with given datatype. (image/paired)
+        Initialize the Dataset Object with given datatype. (image/text/sku)
 
         Args:
             dataset_type (str): DataType of dataset.
@@ -24,7 +25,8 @@ class DatasetInitializer:
         try:
             datasets = {
                 "image": ImageDataset,
-                "paired": PairedDataset,
+                "text": TextDataset,
+                "sku": SkuDataset,
             }
 
             return datasets[dataset_type]
